Skip to contents

A character vector of common spelling, casing, and formatting variants used to refer to the CalFresh program in free-text data.

Usage

calfresh_spellings

Format

A character vector.

Details

This dataset is intended for use in identifying or matching references to CalFresh in survey responses.