Calculate the percentage of occurrences for a value in a column
get_perct.RdThis function calculates the percentage of a value within a column, excluding NA values. It returns the count of the specific value, the total count of non-NA values, and the percentage of the specific value out of all the non-NA values.