Skip to contents

A vector of free-text responses that don't offer much information.

Usage

toss_feedback

Format

A character vector.

Details

This vector includes variations in casing, punctuation, spelling, and phrasing (e.g., "no", "N/A", "none", "Nope", "Thank you", numeric entries, and similar responses).

The vector is intended for use in filtering or normalizing free-text response fields.